####  Bayonet for Python
***

A Python SDK for integrating with the Bayonet API v1. Compatible with Python 2.7.

#### Installation
___
Install via `pip`:

````
pip install bayonet
````

After installation, to get started, open a Python console:

````
from bayonet import BayonetClient
client = BayonetClient()
client.set_api_key([uuid-key])
````

#### Obtaining an access token
___
All requests need to be made with an APIKEY. This key will be provided by Bayonet's team.


#### Example
___


#### Test
___
